@@ -144,8 +144,7 @@ class RestHandler(BaseRequestHandler):
         self.operations = {'list': self.list_objects,
                            'get': self.get_object,
                            'put': self.put_object,
-                           'delete': self.delete_object,
-                           'options': self.send_options}
+                           'delete': self.delete_object}
 
         # allowed operations by request method
         self.allowed_operations = {'get': ['get', 'list'],
@@ -213,14 +212,8 @@ class RestHandler(BaseRequestHandler):
     def options(self, operation):
         """
         Method called on OPTIONS requests.
-
-        Subclasses must implement it.
         """
-        allowed_operations = self.get_allowed_operations('options')
-        operation = operation or 'options'
-        method_to_call = self._validade_operation(operation,
-                                                  allowed_operations)
-        returned = method_to_call(**self.params)
+        returned = self.send_options(*self.params)
         self.write(returned)
 
     def call_method_and_write_json(self, method_to_call):
